@@ -108,13 +108,16 @@
                    $new['toAddress'] = 'on';
                 else
                    $new['toAddress'] = 'off';
-                $new['add_string'] = $_POST['add_string'];
+		if ($_POST['add_string'] != null)
+		$new['add_string'] = $_POST['add_string'];
+                if (get_magic_quotes_gpc() == 1)
+                   $new['add_string'] = stripslashes($new['add_string']);
+		else $new['add_string'] = "";
 		array_push($recipies, $new);
 		write_recipies($file, "/tmp/$FILTERFILE.$username.tmp");
 		filter_put("/tmp/$FILTERFILE.$username.tmp");
 		unlink("/tmp/$FILTERFILE.$username.tmp");
 	} elseif (array_key_exists('modify_x', $_POST)) {
-
 		// Modify an existing entry
                 if ($_POST['field'] == 'X-Spam-Flag')
                    $recipies[$_POST['rule']]['field'] = 'X-Spam-Flag';
@@ -178,8 +181,7 @@
 
 <table width="100%" border=0 cellpadding=1 cellspacing=1>
 <?php
-        if (in_array($username, $ADMIN) && $VIRTUAL_DOMAINS && ($FILE_BACKEND == 'ftp' 
-            || $CREATE_DOT_QMAIL)) {
+        if (in_array($username, $ADMIN) && $VIRTUAL_DOMAINS && ($FILE_BACKEND == 'ftp')) {
            echo "<tr><td bgcolor=$color[4] align=center><br>";
            echo '<center><a href=admin.php>Admin - Set Domain Passwords</a></center>';
            $vdomains = my_list_virtual_domains();
@@ -198,17 +200,17 @@
 <tr><td bgcolor="<?php echo  $color[4] ?>" align=center><br>
 <table border=1 frame=void rules=rows noshade=0 bordercolor=<?php echo $color[0]?> cellpadding=5 cellspacing=0>
 <?php
-     if ($VIRTUAL_DOMAINS && ($FILE_BACKEND == 'ftp' || $CREATE_DOT_QMAIL)) {
+     if ($VIRTUAL_DOMAINS && ($FILE_BACKEND == 'ftp')) {
         list($vuser,$vdomain) = split($SEPERATOR,$username);
         if (!check_pass($vdomain)) {
             echo  _("Your domain") . " ($vdomain) " . _("password is out of date.  Your administrator will need to correct this before you may setup your mailfilters.");
             exit;
         }
-        else
-          $value = print_recipies();
-     } else
-	  $value = print_recipies();
+     }
+     $value = count($recipies);
 ?>
+<tr><td bgcolor="<?php echo  $color[4] ?>" align=center colspan=6>
+<table border=4 rules=rows noshade=0 bordercolor=<?php echo $color[0]?> cellpadding=5 cellspacing=0>
 <tr><td colspan=6 align=center><b><?php echo _("Enter A New Filter:")?></td></tr>
 <form method=post action="options.php">
 <input type=hidden name="create.x" value="<?php print($value++)?>">
@@ -230,7 +232,7 @@
 </tr>
 </table>
 </td>
-<td colspan=4 align=center valign=top><input type=image src="images/saveas.gif" border=0 name=create alt="save new"></td>
+<td align=center valign=top><input type=image src="images/saveas.gif" border=0 name=create alt="save new"></td>
 </tr>
 </form>
 <?php
@@ -255,6 +257,10 @@
                .'<td colspan=4 align=center valign=top><input type=image src="images/saveas.gif" border=0 name=create alt="save new"></td></tr>'
                .'</form>';
        }
+       echo "</table></td></tr>";
+       echo "<tr><td colspan=6 align=center><br><b>"._("Existing Filters:")."</td></tr>";
+
+       print_recipies();
 ?>
 </table>
 <p><b><?php echo _("Notice:") . "</b> " . _("Use of these filters may prevent the reading of mail in non-IMAP mail clients.") ?>
